@@ -39,9 +39,9 @@ def mktorrent(filepath,torrentname,tracker="https://announce.leaguehd.com/announ
             logger.error('删除种子发生错误: %s' %(r))
     logger.info('正在制作种子:'+filepath)
     if 'win' in sys.platform:
-        order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+changename(filepath)+'\"'+''
+        order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+filepath+'\"'+''
     else:
-        order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+changename(filepath)+'\"'+' > /dev/null'
+        order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+filepath+'\"'+' > /dev/null'
     #logger.info(order)
     os.system(order)
     logger.info('已完成制作种子'+torrentname)
